A pairs method that is customized for MCMC
output.
# S3 method for class 'coevfit'
pairs(x, parameters = NULL, ...)An object of class coevfit
If NULL (default), the function returns plots for the main parameters from the model (the selection matrix "A", the drift matrix "Q", and the continuous time intercepts "b"). Otherwise, a character vector declaring the parameters to plot (strictly case-sensitive).
Further arguments to be passed to
mcmc_pairs.
A matrix of output plots
For a detailed description see
mcmc_pairs.
if (FALSE) { # \dontrun{
# fit dynamic coevolutionary model
fit <- coev_fit(
data = authority$data,
variables = list(
political_authority = "ordered_logistic",
religious_authority = "ordered_logistic"
),
id = "language",
tree = authority$phylogeny,
# additional arguments for cmdstanr::sample()
chains = 4,
parallel_chains = 4,
seed = 1
)
# print pairs plot
pairs(fit)
} # }